kubernetes

package
v0.2.0-rc.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EnsureAnnotations

func EnsureAnnotations(o metav1.Object, toEnsure map[string]string)

EnsureAnnotations merges the given annotations into the object's existing annotations. Existing annotations are preserved, new annotations are added, matching keys are overwritten.

func EnsureLabels

func EnsureLabels(o metav1.Object, toEnsure map[string]string)

EnsureLabels merges the given labels into the object's existing labels. Existing labels are preserved, new labels are added, matching keys are overwritten.

func GetCredentialFromSecret

func GetCredentialFromSecret(ctx context.Context, client ctrlruntimeclient.Client, namespce string, name string, key string) (string, error)

GetCredentialFromSecret get the secret and returns secret.Data[key].

func PatchObject

func PatchObject(ctx context.Context, client ctrlruntimeclient.Client, obj ctrlruntimeclient.Object, modify func()) error

Types

This section is empty.

Jump to