Documentation
¶
Index ¶
- func EnsureAnnotations(o metav1.Object, toEnsure map[string]string)
- func EnsureLabels(o metav1.Object, toEnsure map[string]string)
- func GetCredentialFromSecret(ctx context.Context, client ctrlruntimeclient.Client, namespce string, ...) (string, error)
- func PatchObject(ctx context.Context, client ctrlruntimeclient.Client, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnsureAnnotations ¶
EnsureAnnotations merges the given annotations into the object's existing annotations. Existing annotations are preserved, new annotations are added, matching keys are overwritten.
func EnsureLabels ¶
EnsureLabels merges the given labels into the object's existing labels. Existing labels are preserved, new labels are added, matching keys are overwritten.
func GetCredentialFromSecret ¶
func GetCredentialFromSecret(ctx context.Context, client ctrlruntimeclient.Client, namespce string, name string, key string) (string, error)
GetCredentialFromSecret get the secret and returns secret.Data[key].
func PatchObject ¶
func PatchObject(ctx context.Context, client ctrlruntimeclient.Client, obj ctrlruntimeclient.Object, modify func()) error
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.